@@ -14,9 +14,11 @@ var app = new Vue({
     show_tables: {
       pending: true,
       current: true,
-      finished: true,
+      finished_done: true,
+      finished_skipped: true,
       error: true
     },
+    finished_count: 0,
     skipped_count: 0
   },
   computed: {
@@ -31,18 +33,22 @@ var app = new Vue({
       const json_data = JSON.parse(event.data)
 
       self.state = json_data.state
-      if (self.state.folders.length === 1) {
+      if (!self.selected_folder && self.state.folders.length > 0) {
         self.selected_folder = self.state.folders[0]
       }
 
       self.pending_uploads = json_data.pending.filter(u => u.file_path.startsWith(self.selectButtonTitle))
       self.current_uploads = json_data.current.filter(u => u.file_path.startsWith(self.selectButtonTitle))
-      self.finished_uploads = json_data.finished.filter(u => u.file_path.startsWith(self.selectButtonTitle))
       self.error_uploads = json_data.errors.filter(u => u.file_path.startsWith(self.selectButtonTitle))
 
-      self.progresses = self.current_uploads.map(u => u.progress)
+      self.finished_count = json_data.finished.length
+      self.skipped_count = json_data.finished.filter(u => u.substatus.toLowerCase().startsWith('skipped')).length
 
-      self.skipped_count = self.finished_uploads.filter(u => u.substatus.startsWith('skipped')).length
+      self.finished_uploads = json_data.finished
+        .filter(u => u.file_path.startsWith(self.selectButtonTitle))
+        .filter(u => (u.substatus.toLowerCase().startsWith('skipped') && self.show_tables.finished_skipped) || (!u.substatus.toLowerCase().startsWith('skipped') && self.show_tables.finished_done))
+
+      self.progresses = self.current_uploads.map(u => u.progress)
     }
   }
 })
